### Changelog

All notable changes to this project will be documented in this file. Dates are displayed in UTC.

Generated by [`auto-changelog`](https://github.com/CookPete/auto-changelog).

#### [Unreleased](https://github.com/dustindall/footings/compare/v0.8.1...HEAD)

#### [v0.8.1](https://github.com/dustindall/footings/compare/v0.8.0...v0.8.1)

> 14 November 2020

- Updated readme badge link. [`cdd65db`](https://github.com/dustindall/footings/commit/cdd65dbf58e397332d7881c5eb34cdcae920248a)

#### [v0.8.0](https://github.com/dustindall/footings/compare/v0.7.0...v0.8.0)

> 13 November 2020

- Added make_foreach_model and convert_to_recrods under model_tools. [`9a8dcd3`](https://github.com/dustindall/footings/commit/9a8dcd3db9cb539c0fc1e69e1976d8628f1aff1c)
- Removed changelog.md [`19a1214`](https://github.com/dustindall/footings/commit/19a12144229ce90e68a138d6e00f947006bfe9f5)
- Refactored sub packages to be doc_tools, test_tools, and model_tools. [`d9de48c`](https://github.com/dustindall/footings/commit/d9de48cb1f58fe94152105694225ffa0cc3758da)
- Expanded fields in __footings__ xlsx log to include source, mapping, end_point, and column_name. [`f5bc923`](https://github.com/dustindall/footings/commit/f5bc9237e359075023ef64ee77e547db7b8b5eaa)
- Updated footings.tools in user guide to be footings.model_tools. [`0e0c35a`](https://github.com/dustindall/footings/commit/0e0c35abb76403345ca57bdee839bb3a07b29ef5)
- Added source to output for audit xlsx file. [`44e75ad`](https://github.com/dustindall/footings/commit/44e75ad77fd5f8c87a4077f5af042457ef107c7c)
- Updated changelog. [`eb5f54c`](https://github.com/dustindall/footings/commit/eb5f54ce05da0eeb6bed62b0f38a49c3e47fda3f)
- Modified ordering of parameters and now run to_step returns self. [`cdb44dd`](https://github.com/dustindall/footings/commit/cdb44dd4cad6094080f28034065778abb0390ac7)
- Updated build-n-publish to be triggered only on tag push. [`0f0e16e`](https://github.com/dustindall/footings/commit/0f0e16ebb4d745823a20dd13684006a2142630f3)
- Updated ordering of attributes. [`775e242`](https://github.com/dustindall/footings/commit/775e24249eb0229784c54ef9fba9bb32708b7921)
- Changes doc_tools test of generated rst to strip new lines on spaces. [`4dca72a`](https://github.com/dustindall/footings/commit/4dca72a234026ad2fc77c463b1cdaa45616acce4)
- Added if success status is success in order to publish to pypi. [`2fb5084`](https://github.com/dustindall/footings/commit/2fb508469b030cc5479dbbedac903a823a3effa2)
- Added test of hasattr  __str__ when writing to xlsx. [`cec4d7f`](https://github.com/dustindall/footings/commit/cec4d7fe0340bf632f2e11068093c8548fb61000)
- Updated conf.py to use doc_tools and not doctools. [`7ecbb73`](https://github.com/dustindall/footings/commit/7ecbb7394f010e254f74919663dded5a0f8d5c72)
- Added dask to environment. [`a7c3614`](https://github.com/dustindall/footings/commit/a7c3614e6edb584a726367eb5935dd6794864e53)
- Added if success status is success in order to publish to pypi. [`0a7326d`](https://github.com/dustindall/footings/commit/0a7326db503fa7a5ab6ea4146ddb32ae9dcedf85)

#### [v0.7.0](https://github.com/dustindall/footings/compare/v0.6.0...v0.7.0)

> 15 October 2020

- Updates with major refactoring of footings framework. [`e000696`](https://github.com/dustindall/footings/commit/e000696148a669fd6926205c0f6733a4b6dd420c)
- Added test for doctools. [`8ccbe0d`](https://github.com/dustindall/footings/commit/8ccbe0d071617d6aae88c0ade30b829a57cc51cd)
- Updates to documentation for new api. [`f3bc2dc`](https://github.com/dustindall/footings/commit/f3bc2dc39f631d37017a3deb3738e140fe085a4b)
- Updated tests with new assert_footings_audit_xlsx_equal. [`9bfdf03`](https://github.com/dustindall/footings/commit/9bfdf03e0ebb60e729d5db38f3b48b634a6f02ed)
- Some refactor updates to xlsx.py and audit.py. [`a025c41`](https://github.com/dustindall/footings/commit/a025c417e9adb04e6c1bd7f4272b60d3a509be6a)
- Removed .ipynb from .gitignore so user_guide.ipynb file could flow through to documentation. [`34629fc`](https://github.com/dustindall/footings/commit/34629fc850b14d21ae9d8fa6f1d6195c22ee8acf)
- Updated to footings/core. [`68e92ca`](https://github.com/dustindall/footings/commit/68e92ca9b733f51cc15a09e51789206a64bbe3a6)
- Added doctools as package. [`7835c9c`](https://github.com/dustindall/footings/commit/7835c9c4899637017811254a9b1b62c9c0f882e5)
- Added changelog using auto-changelog. [`2014ab8`](https://github.com/dustindall/footings/commit/2014ab82d447e694a536ceeafe22d8ee02029938)
- Additions and updates to doctools features under new api design. [`bedfe9a`](https://github.com/dustindall/footings/commit/bedfe9ae03114440b2dc4e1f01d5e818a69be249)
- Improvements to the aesthetics of generating xlsx audit files. [`81e3eb4`](https://github.com/dustindall/footings/commit/81e3eb481f3379dbf12a95a887aaa83c0291a9f2)
- Build out of load_footings_audit_xlsx and assert_footings_audit_xlsx_equal. [`09c299f`](https://github.com/dustindall/footings/commit/09c299fb0eb42ab58a03ef948734b3de14beb988)
- Last updates to core footings features under new api design. [`b4ba7a1`](https://github.com/dustindall/footings/commit/b4ba7a1ce38a152036e8dfeb71ed9f3441d1393d)
- Updates to documentation generator. [`3c8a544`](https://github.com/dustindall/footings/commit/3c8a544f0343ca6f9787f370cf1b02e8b014cc13)
- Updates to tools features under new api design. [`e527fbd`](https://github.com/dustindall/footings/commit/e527fbdb9ec93daf87e0a0f08d55c64dec75e27a)
- Refactored testing of html file produced by footins.doctools. [`c2c4815`](https://github.com/dustindall/footings/commit/c2c4815add501f29e82dd89b00ff3fe49f7e71e2)
- Added dev branch to ci action and loosened tag criteria for build action. [`87d4eec`](https://github.com/dustindall/footings/commit/87d4eec89216f6933fd910cb68a197c8ecd3c0a0)
- Major refactoring to test_model.py [`3692df6`](https://github.com/dustindall/footings/commit/3692df663887bb1364c4a21de32ad36a0c09d937)
- Added ipython to environement file, fixed conf and api files, as well as added more documentation to __init__ files. [`afc6dd8`](https://github.com/dustindall/footings/commit/afc6dd8e1e39dfa2de00024a89debe7ae7f44c3a)
- Refactor audit.py and xlsx.py and added some fixes. [`81d22b3`](https://github.com/dustindall/footings/commit/81d22b391a35d08410a95ebebe17d0df9577d034)
- Move test automations from tox to nox. [`b62852e`](https://github.com/dustindall/footings/commit/b62852eae641dfebfd6a7965134c241ed120ad94)
- Fix to test to use environments-dev as opposed to test given reliance on sphinx and a few other items. [`7cfc755`](https://github.com/dustindall/footings/commit/7cfc7554cc01751bb7a5896a30acb192ae09b1ee)
- Added workflow action on master branch to publish to pypi. [`38bbe51`](https://github.com/dustindall/footings/commit/38bbe51774237ac9639ef5c43e816ae758c8686a)
- Change to readthedocs.yml file. [`7aa8b08`](https://github.com/dustindall/footings/commit/7aa8b086401e455089e78675e9cf701d414cb35a)
- Test work to use nox. [`e0329ca`](https://github.com/dustindall/footings/commit/e0329ca5fd087fd48db961e8edfbab69f07995c5)
- Added github action to publish package to test.pypi and pypi. [`18d10dc`](https://github.com/dustindall/footings/commit/18d10dc7bdb4499141f7190b4bbbe6b356c7f72e)
- Creation of environments folder with separate environment files for dev, test, and base. [`5608ebc`](https://github.com/dustindall/footings/commit/5608ebc39b9753567e317d989cc443e5fa449202)
- Added changelog session to nox. [`5bd50bd`](https://github.com/dustindall/footings/commit/5bd50bd4d6582c239ce09cbc00695224241c3666)
- Update to manifest.in [`0f9d6cb`](https://github.com/dustindall/footings/commit/0f9d6cb0d40bbeb06b5685497afed19038568c81)
- Fix to test to use environments-dev as opposed to test given reliance on sphinx and a few other items. [`d571dc8`](https://github.com/dustindall/footings/commit/d571dc81703c45732ab2181daa692c20b5ae96d4)
- Added ability to run model to specfic step. [`0190a48`](https://github.com/dustindall/footings/commit/0190a48266d45755128a6a01c85f562519e464f8)
- Added logic to remove the first set of indents for docstrings. [`5a61776`](https://github.com/dustindall/footings/commit/5a617769769faea402772aa7e1d6708bb4054574)
- Added name of paramter to error output. [`50b3461`](https://github.com/dustindall/footings/commit/50b3461a237c215062a8256383ab877486e8bd4a)
- Update to test suite for github actions. [`7feab66`](https://github.com/dustindall/footings/commit/7feab66ee63d30043509c6a11c364ce5ca50b869)
- Added sphinx extensions to extras in setup.cfg and updated README.md. [`66810f1`](https://github.com/dustindall/footings/commit/66810f17bc242a324b9efe2cd8d5821e8d85af95)
- Removed environment-test.yml file as the dev file is being used for testing. [`38dacab`](https://github.com/dustindall/footings/commit/38dacabed5cdb4b478ce67361b4d404a8f01ffc0)
- Update to noxfile. [`44aef17`](https://github.com/dustindall/footings/commit/44aef1780253b2833d44fb9a8d97762b49a7d6a5)
- Change to readthedocs.yml file. [`0f4f682`](https://github.com/dustindall/footings/commit/0f4f682e325a8c01db7778a8db8fa03936f92e4c)
- Change to readthedocs.yml file. [`388d48a`](https://github.com/dustindall/footings/commit/388d48ab9b10e6485a12f3efa267ddc58351a3d0)
- Add missing $ sign. [`2319207`](https://github.com/dustindall/footings/commit/2319207051cd994f43023614ce3a947c4c6cf894)
- Fixes to address failed test. [`f844e12`](https://github.com/dustindall/footings/commit/f844e124f0b2f07784648fc1d05b709069ad3c2a)
- Added missing sphinx extensions to environment-dev.yml. [`5ce0234`](https://github.com/dustindall/footings/commit/5ce023421795913015fb3da72677809902857d51)
- Added type to attrib and name of model as return. Both improve the use of type hints when using sphinx. [`96cfeb8`](https://github.com/dustindall/footings/commit/96cfeb8a6062f9c92936ed86609a7dbfe8b5a35f)
- Included new tools assert_audit_xlsx_equal and load_footings_audit_xlsx in docs. [`d9f91de`](https://github.com/dustindall/footings/commit/d9f91de34702cc334d539d881dfe12893f878f8d)
- Update to noxfile. [`81e5158`](https://github.com/dustindall/footings/commit/81e51584c398ae9a53bc30489896627d10b29755)
- Added output_type to run audit. [`260cb7c`](https://github.com/dustindall/footings/commit/260cb7cc74a0db53eea80b277683eefee024333a)
- Added dev branch to ci action and loosened tag criteria for build action. [`23a0690`](https://github.com/dustindall/footings/commit/23a06901daf0327c1cfadf319582d0d633b1a7c3)
- Updates to ci.yaml file. [`90668da`](https://github.com/dustindall/footings/commit/90668da1752845c4d4f49d2f8f4464414ea4ed12)
- Added conda environemnt to readthedocs.yml. [`0f236b4`](https://github.com/dustindall/footings/commit/0f236b4ca126d9a83688725315c2e02cd4f21fad)
- Add mathcing criteria to tags. [`5509680`](https://github.com/dustindall/footings/commit/5509680232fb2d47b6c9b5bca571b7908dbb1cb8)
- Removed python 3.6 from test suite. [`6f6f242`](https://github.com/dustindall/footings/commit/6f6f242434cff6a982a3b5a4b24bf55da27759f5)
- Changed test environment to use dev. [`a94df49`](https://github.com/dustindall/footings/commit/a94df49259d62bbb74f383ec1bcbbb00b23703b5)
- Moved numpy to top of dev envioronment file. [`5ab80e7`](https://github.com/dustindall/footings/commit/5ab80e7a13dcc94a02bff3e79db28252f0a13c8f)
- Removal of release from tag prefix and branch from action. [`05df697`](https://github.com/dustindall/footings/commit/05df697535df16952a799543da03b90639a855b5)
- Add mathcing criteria to tags. [`c478480`](https://github.com/dustindall/footings/commit/c4784809485a525bd8888b10538316b904b28730)
- Fix github actions nox run tests. [`f4eb211`](https://github.com/dustindall/footings/commit/f4eb2113a44f12be08b6ac0a97b7b21f90604580)
- Fix github actions file name. [`bc62e18`](https://github.com/dustindall/footings/commit/bc62e1819288acdb2bdb5199dd99fb6f20277360)
- Add missing $ sign. [`b9462c4`](https://github.com/dustindall/footings/commit/b9462c454f08273b748078aa865d8dc74adb9e60)
- Fix repository url for test.pypi. [`03bf407`](https://github.com/dustindall/footings/commit/03bf407af3698ba03a23300f1d55fe1c3837699f)
- Anchor numpydoc at v1.0.*. Need to research why v1.1.0 is failing. [`553cec6`](https://github.com/dustindall/footings/commit/553cec6313690798f4f5e60ec2a9c8835b64fc8a)
- Added version to black repo in pre-commit-config. [`6a2df87`](https://github.com/dustindall/footings/commit/6a2df8731e44cf58d16d7fbfc32e4cebec2f4221)
- Added file to audit. [`25bf5f9`](https://github.com/dustindall/footings/commit/25bf5f9ba1bcb02e38082001bb2fc6440a85fb79)
- Changed venv from conda to None. [`7008320`](https://github.com/dustindall/footings/commit/70083202f93c429a7078d07c72fb1f82c7a7fc48)
- Changed tag_prefix for versioneer. [`be87232`](https://github.com/dustindall/footings/commit/be87232ab8f9262e8d691af669259d1b0cff8a50)
- Updated noxfile to use dev environement. [`a3ba0b4`](https://github.com/dustindall/footings/commit/a3ba0b4e0fe6c72acc68976366b2fcc142943f51)
- Changed venv from conda to None. [`3b870fd`](https://github.com/dustindall/footings/commit/3b870fd09099159e838b68d0fd61684f4b488663)
- Added numpy to dev envioronment file. [`7f507c2`](https://github.com/dustindall/footings/commit/7f507c29adb7566d4e490ebf0687c5ced6e2296e)
- Removed toolz from install_requires. [`6173a6d`](https://github.com/dustindall/footings/commit/6173a6dfdd1a7b852ca9bbec51c0af82c58ab9a8)
- Added file removal when building docs. [`df99c7d`](https://github.com/dustindall/footings/commit/df99c7d13bbfbb7ddb1af5371b23adbb73c58016)
- Removed python 3.6 from classifiers. [`75f6b6e`](https://github.com/dustindall/footings/commit/75f6b6ec11ae956b48438afc7186575f497fadfd)
- Removed batch from footings. [`02eb17e`](https://github.com/dustindall/footings/commit/02eb17e434d9035e6a9a8e86347b6e7789639eb7)

#### [v0.6.0](https://github.com/dustindall/footings/compare/v0.5.0...v0.6.0)

> 12 July 2020

- Changed Argument to Parameter. [`59ba94e`](https://github.com/dustindall/footings/commit/59ba94e472848c681d36e5d48aa3d59c32d75689)
- Refactoring of dispatch_function and loaded_function. [`0643d0a`](https://github.com/dustindall/footings/commit/0643d0a40b3e1354eab2ba9a050bb8f3d57e1021)
- Updates to test using refactored dispatch and loaded function and renamed build_model and define_parameter. [`318d2c4`](https://github.com/dustindall/footings/commit/318d2c43ca2a7cd7b2add34e37f13e4c09634db0)
- Added steps section to model docstring, refactored some code, started move to parameters vs arguments. [`afa8aba`](https://github.com/dustindall/footings/commit/afa8abad160ac28617bb3997795180cb4d014383)
- Added custom properties for  __name__ and __doc__. [`088ec7d`](https://github.com/dustindall/footings/commit/088ec7dcd67397144e529c9339ee8cefb58a6eff)
- Updates using refactored dispatch and loaded function and renamed build_model and define_parameter. [`924bc74`](https://github.com/dustindall/footings/commit/924bc749e5806de72ae06cba1b57529a5788eacc)
- Updates to docs using refactored dispatch and loaded function and renamed build_model and define_parameter. [`8ed8f0a`](https://github.com/dustindall/footings/commit/8ed8f0a7778b169422392b504b6d77cb6ec1fd17)
- Refactored create_model_docstring and added run method to docstring. [`8d1ad93`](https://github.com/dustindall/footings/commit/8d1ad93833b921ad15447f79e4f6775680fa41fd)
- Moved auit to use parameters and made docstring optional in utils. [`b95275d`](https://github.com/dustindall/footings/commit/b95275d7b9c8b79feda172c7d90ba5b84003b461)
- Updated api doc to use parameter. [`aa69d58`](https://github.com/dustindall/footings/commit/aa69d584e68e6969832fa5b70219a04d4605f21e)

#### [v0.5.0](https://github.com/dustindall/footings/compare/v0.4.0...v0.5.0)

> 28 June 2020

- Added frame calculations to library as well as updated documentation. [`a5ec427`](https://github.com/dustindall/footings/commit/a5ec4279b9cd71bfd593c47bcac7e56bb41ac50f)
- Updates to documenation to calculate age. [`a70d722`](https://github.com/dustindall/footings/commit/a70d7222095eabc9258b814d73db110033dca3ac)
- Added post_drop_columns to library as a helper function. [`162d511`](https://github.com/dustindall/footings/commit/162d5118d96d24cc15aecda0f9732babae7ba9ca)
- Made calculate age return int32 for series. [`2894047`](https://github.com/dustindall/footings/commit/2894047a0a72140263356b081610a5713fce4a93)
- Renamed footings.library to footings.tools [`911450f`](https://github.com/dustindall/footings/commit/911450f7e37c0e92ee38a6a5a571c7207d2b0c93)
- Changed created model to use Parameters as opposed to Attributes. [`34d4c92`](https://github.com/dustindall/footings/commit/34d4c92472d09ac0d819e8654925878972b6b6e9)
- Added ignore bare excep to flask config. [`4b6c548`](https://github.com/dustindall/footings/commit/4b6c5488189c73a229f1ad26ee1b7695ca449e54)
- Fixed long description issue in setup.cfg. [`7051881`](https://github.com/dustindall/footings/commit/705188116f4963a3e12b40ac56bd688cb151d6b9)
- Removed intended actuaries from setup.cfg. [`1d2c35e`](https://github.com/dustindall/footings/commit/1d2c35eea4e03e44203e7efe0f36e9ccb07d869b)

#### [v0.4.0](https://github.com/dustindall/footings/compare/v0.3.0...v0.4.0)

> 22 June 2020

- Updates to test and move to tox. [`34a133b`](https://github.com/dustindall/footings/commit/34a133bed012e5d5a6babd8534187aa0bfe62da2)
- Moved repo to be under src and added core and library sub modules. [`28b22af`](https://github.com/dustindall/footings/commit/28b22af7da04af67201390f92893e4608a6255da)
- Added pytest logging to xlsx comaprison. [`4667108`](https://github.com/dustindall/footings/commit/4667108ff371d85eda92d98621a6d52e00038dde)
- Added tox-gh-actions and fixed pre-commit dependency [`4132e86`](https://github.com/dustindall/footings/commit/4132e86fd4488e014210fb40a3879d0ac3d87022)
- Updated to readme.md [`f9a2073`](https://github.com/dustindall/footings/commit/f9a207329a92141c5babe58975c1b3c26a988b30)
- Removed _rels/.rels from xlsx comparison. [`3c77f76`](https://github.com/dustindall/footings/commit/3c77f769c9d6cc486b0227fe8da1cabb380bd2cf)
- Removed xl/_rels/workbook.xml.rels from xlsx comparison. [`6ae5cdc`](https://github.com/dustindall/footings/commit/6ae5cdcc30545859c9e7844f86b223b654305338)
- Added readthedocs.yml file. [`b965320`](https://github.com/dustindall/footings/commit/b965320d515541d182f4ca84acb2a5dfcf8f62ce)
- Removed [Content_Types].xml from xml check of excel files. [`8639c6b`](https://github.com/dustindall/footings/commit/8639c6b7361d290e5b28d608a6577fae4e541e89)
- Removed pypy3 from tests. [`afdff65`](https://github.com/dustindall/footings/commit/afdff65692a60cc11305a00b63f9741b4284e7f1)
- Add xml output to logger. [`586dc5f`](https://github.com/dustindall/footings/commit/586dc5f9e4ae3d12fec5c57f049cb34de59bb078)
- Added exclude to pre-commit per flask8 docs. [`e0190c1`](https://github.com/dustindall/footings/commit/e0190c1a4d387b20a6fe5c808213d23f6f4a10dd)
- Added master_doc and version lookup within conf.py [`b4f5e8a`](https://github.com/dustindall/footings/commit/b4f5e8a98e69f54bacdae29a678123bd696165e8)
- Added additional badges to readme. [`6d9c683`](https://github.com/dustindall/footings/commit/6d9c683ea4e688c8944d8ac9c7d02b82865df2e7)
- Removed docProps/core.xml from xlsx comparison. [`8295338`](https://github.com/dustindall/footings/commit/82953386c7d775d71134cdc53121dc7428e06c19)
- Removed [Content_Types].xml from xml check of excel files. [`ee1d113`](https://github.com/dustindall/footings/commit/ee1d113f3c7a59ddb916b4d89dcd6dc2ce08dca8)
- Removal of formatting from setup.cfg. [`60f23ef`](https://github.com/dustindall/footings/commit/60f23ef24e69cec4c11f63cfb1540516f1b6080f)
- Added last comment to principles. [`cdfa88f`](https://github.com/dustindall/footings/commit/cdfa88f5822fcb2d60cfccd9e27df93df1f1d1bf)

#### v0.3.0

> 15 June 2020

- Moved to versioneer to manage versions. [`6e191a9`](https://github.com/dustindall/footings/commit/6e191a9fb2ef270d8947396f5bf2fe9b15439442)
- Transitioned to attrs [`69e08bd`](https://github.com/dustindall/footings/commit/69e08bd77c55397b0accdd7f0346bbc4ef0f7722)
- major upgrade to ffunctions [`b35fd5a`](https://github.com/dustindall/footings/commit/b35fd5a8bf73a9a28d3279b16ad98bc3de19d541)
- Bulk update with  new framework. [`377027e`](https://github.com/dustindall/footings/commit/377027e0c8dd281791290ae62dff0511e8350c5c)
- big change moving to futures [`c3fcb79`](https://github.com/dustindall/footings/commit/c3fcb79da86bede9b5f2e8dbf02f36e5ba5846de)
- major update to refactoring [`9ddfb78`](https://github.com/dustindall/footings/commit/9ddfb787e1fa65feffb5c9b4bbdf0c29829ed205)
- Inital commit of working files [`fa52375`](https://github.com/dustindall/footings/commit/fa52375c8484715148df1f2b485ba6b9e7d64be2)
- bulk updates [`7660075`](https://github.com/dustindall/footings/commit/7660075f4734c848f005fb59ba437c8e6fa855c9)
- Start to major refactoring [`02773a1`](https://github.com/dustindall/footings/commit/02773a147037d291ee71e403b2a7552a11ad62a0)
- Bulk updates. Reworked task and starting an error file. [`21521af`](https://github.com/dustindall/footings/commit/21521af5fd3da549daf3c024f55c568d15519d71)
- before move to dataclasses [`6488950`](https://github.com/dustindall/footings/commit/64889502a062b82b7292a9371fe23052845318da)
- Updates to pass tests [`6862151`](https://github.com/dustindall/footings/commit/68621510314833ad594e873845f49119552d33f2)
- Added documentation. [`5e33e1f`](https://github.com/dustindall/footings/commit/5e33e1f16987bd8f8e30e3abbc515cc9d6ef50c6)
- Major update to use object ModelTemplate [`2dc29b0`](https://github.com/dustindall/footings/commit/2dc29b094e96598a182f357f5909f0f597c88f9c)
- before switch on ffunctions [`e4697b6`](https://github.com/dustindall/footings/commit/e4697b6be82ff3c0beb3606888c07dbc62238093)
- Added capability to parse annotations from docstring and refactored code base [`a113897`](https://github.com/dustindall/footings/commit/a113897c5d57c6f6135b7e7bd6715ba50a00f3e8)
- Addition of output to_xlsx using the writexlsx library. [`9398d81`](https://github.com/dustindall/footings/commit/9398d817fdc61616dcd9d6cad05cca367055c3c5)
- Updates and documentation for annotation sections [`c94cecb`](https://github.com/dustindall/footings/commit/c94cecb90e163f709d56c257cad36f1590489b5c)
- Moved schema to footings_library. [`aaceb30`](https://github.com/dustindall/footings/commit/aaceb302dae02461a4cc7ef8ae6a64236550b628)
- Applied black formatting [`7ee521d`](https://github.com/dustindall/footings/commit/7ee521dc907cfb9d29dead8e5e66b74cdbe4ceee)
- Added capabilty get_attr and get_key for dependents. [`88533bc`](https://github.com/dustindall/footings/commit/88533bcfc6ddb891b480ab6b161715e19ec98315)
- to dask dataframe working version [`4ecc54f`](https://github.com/dustindall/footings/commit/4ecc54fe61556d255af6ec4406bbabd0e55a34d9)
- First pass at creating model audit capabilities. [`0a2d83f`](https://github.com/dustindall/footings/commit/0a2d83ffad40653c448758602c5d361c213951be)
- Additional work to function.py [`cb1e822`](https://github.com/dustindall/footings/commit/cb1e8220579a089c52b1739c36560e20b1e401b8)
- back to dask delayed and dataframe [`03e0988`](https://github.com/dustindall/footings/commit/03e098823c3179d95df81361bf42b6c51c3645ba)
- Added NestedFunction and TblFunction functionality to footings. [`ca09ebb`](https://github.com/dustindall/footings/commit/ca09ebb0554d3c20f41b992230799a52c42ce051)
- Intermediate steps [`0f290b8`](https://github.com/dustindall/footings/commit/0f290b87fe53dd2d863a6be1a7ec0f2b9b0c0130)
- Updated pass on developing audit to xlsx framework. [`b41fda0`](https://github.com/dustindall/footings/commit/b41fda004aba7dd14675e1650e295c8fa7501764)
- before change in val wrapper [`ea4a758`](https://github.com/dustindall/footings/commit/ea4a7585c3f69af1f869a72712bc4fea36137774)
- First pass at sphinx. [`9910891`](https://github.com/dustindall/footings/commit/991089117c605bd4e0a20e6b76d3115afad474fc)
- refactored model; a singled function is now applied to map_paritions; added meta info [`94875af`](https://github.com/dustindall/footings/commit/94875af0ef770dea864615eeb875f918c203ad99)
- Updates to major refactoring [`917e5c9`](https://github.com/dustindall/footings/commit/917e5c9faf9105f4555cc99018796b9af783f5a1)
- Added capability to provide custom output type to model. [`b2aa48a`](https://github.com/dustindall/footings/commit/b2aa48a18cc0fe23752dfc2f6d8c2ba68d325981)
- Major refactoring - moved ff_function to function section, removed ModelGraph, relied more on Registry, Simplified ModelTemplate [`6943cbb`](https://github.com/dustindall/footings/commit/6943cbba0247532f4651ea87236938dfc095132e)
- Updates to footing.py and test_footing.py. [`4577272`](https://github.com/dustindall/footings/commit/45772725703ac25d40afc7c63ee7c93013d5293e)
- Revamped testing layout for model [`1a91f72`](https://github.com/dustindall/footings/commit/1a91f72823452a8c3f3c9a3525ff6194b172acef)
- Updates to graph and model [`f33c168`](https://github.com/dustindall/footings/commit/f33c168bfd4e0d7e8fef9b3e9459f99c005668a5)
- fixes to model [`7e5cd7c`](https://github.com/dustindall/footings/commit/7e5cd7cb9c0f25b9f5f92cddfe26d9f111ad36b2)
- Updates to model. [`d23f359`](https://github.com/dustindall/footings/commit/d23f3594d5a73ee40d9effdc687d76144bea2c7b)
- First attempt mkdocs. [`9c8855b`](https://github.com/dustindall/footings/commit/9c8855b6d12e0c3ae7eb142e48e095ce324cd574)
- Moved from xlsxwriter to openpyxl. [`3e9a27c`](https://github.com/dustindall/footings/commit/3e9a27cbe03cd597f0c9ad61a89c1e78d676f41d)
- Removed ffunction.py and associated test file. [`e59837f`](https://github.com/dustindall/footings/commit/e59837f2054c21739bfceb094e28ca98516d90ab)
- Moved to using list for input and output columns [`0607144`](https://github.com/dustindall/footings/commit/060714468fa82143a1c4bdd27a11552382b8ef66)
- Updates to utils.py. [`5f7569b`](https://github.com/dustindall/footings/commit/5f7569b406442a1ec5194494e7568143f98fe9cb)
- Added functionality for Dispatcher. [`d510d60`](https://github.com/dustindall/footings/commit/d510d6079ea6ce0f5a757be0659c172d80f6adfe)
- Updates to docstrings for sphinx. [`4167164`](https://github.com/dustindall/footings/commit/4167164f99272f385e80409a09425deddbb314b9)
- Removed need for output_src from model. [`4f977b6`](https://github.com/dustindall/footings/commit/4f977b65a9d0d498ce41a13b44b0712b9de69b46)
- added pre-commit-config, model test, and assumptions code and test [`1ad1f78`](https://github.com/dustindall/footings/commit/1ad1f7847e1368f6418e419e583d488c22a183e3)
- Refactored to dispatch on keys. [`54c7d56`](https://github.com/dustindall/footings/commit/54c7d56bdaf0d423bba71e0b709aedb4299fa332)
- Updates to config files as well as some fixes. [`f3b3255`](https://github.com/dustindall/footings/commit/f3b3255af86d19818f64848e70c1fc1c8b0ec459)
- interim updates to model api [`5ac0c04`](https://github.com/dustindall/footings/commit/5ac0c04b89a56efd0d98344fc898be2d6efa3f8d)
- updated expand_frame [`121d6b1`](https://github.com/dustindall/footings/commit/121d6b156dd154cdef750269b2f3d1dfa528429f)
- updates to model [`7dbb4f5`](https://github.com/dustindall/footings/commit/7dbb4f52ea3d03df5e03ca1add3a006721824a23)
- Updates to audit. [`944d2f9`](https://github.com/dustindall/footings/commit/944d2f91ee8aeb5dee2d556b9896fae2eca17b9e)
- reformatted test [`ca8989b`](https://github.com/dustindall/footings/commit/ca8989b93100616b402c4016275911b68a1845ac)
- Updates to ffunction and table_schema [`f357284`](https://github.com/dustindall/footings/commit/f3572843bd25b756debac8b9e4726cae1b79639c)
- ran flake8 [`1bac4f6`](https://github.com/dustindall/footings/commit/1bac4f6b533e2ecbc5c6f53eea3c731634afb5c1)
- Utilizing a shared module for steps and footings in testings. [`207bcc3`](https://github.com/dustindall/footings/commit/207bcc3bff3a38b1602cad23e17041357ef78ed6)
- Initial commit [`76d22d0`](https://github.com/dustindall/footings/commit/76d22d019c8ed3a493b9dd10e1eb2c18d5cdeb66)
- Fixed some linting errors and added pre-commit hooks. [`798826f`](https://github.com/dustindall/footings/commit/798826f634fc744aac3fcf92d30e94a783d535b4)
- table_schma first pass with test [`f37c483`](https://github.com/dustindall/footings/commit/f37c4830dcd0534aecf72d25e4ddac8e4f9faf68)
- Refactoring to include subpackages https://github.com/dustindall/footings-core/issues/8 [`9eee5dd`](https://github.com/dustindall/footings/commit/9eee5ddaa4e063405840255567cf2c2058ece855)
- before moving attrs [`bd2946b`](https://github.com/dustindall/footings/commit/bd2946b37fab24f02bdd188f287ece4d57548592)
- Fixes to ci.yaml and the associated failed test. [`b43e5f2`](https://github.com/dustindall/footings/commit/b43e5f2393ba7b9a482b746d69eddc2f4276b0d5)
- Added error if using a footings reserved word. [`d1a722a`](https://github.com/dustindall/footings/commit/d1a722a75c0063d70dbb426e9b33b3157b4d1039)
- Small changes to files. [`947cd78`](https://github.com/dustindall/footings/commit/947cd784fadd09b10cd3f20c13eb587c386fa014)
- brought dask.delayed [`db2f280`](https://github.com/dustindall/footings/commit/db2f28074517daa5cec00d08d61c5dfaf1a8811b)
- Cleaned and prepared arguments module. [`7232390`](https://github.com/dustindall/footings/commit/7232390e4a1b7f9d84179171f26794306d63b52e)
- Added create_argument function. [`f95f2ac`](https://github.com/dustindall/footings/commit/f95f2aca3a5f0a9d38c08891c922babb2a786267)
- Changed types to be annotations and split assumptions to be stochastic and deterministic [`17a1232`](https://github.com/dustindall/footings/commit/17a12321b47d4ed1356a4fc49ed2e225f5d517e8)
- Refactored LoadedFunction to use a list as a registry. [`5696540`](https://github.com/dustindall/footings/commit/5696540ad6669f686e1c9721cbb3f103dd92199f)
- Fixed setup.py and added MANIFEST.in [`ed1e873`](https://github.com/dustindall/footings/commit/ed1e873f6ff0cd561350d63c863735030b18bfef)
- Cleaned and prepared model  module. [`0a0b4f1`](https://github.com/dustindall/footings/commit/0a0b4f1eb501488f1621d3b22e76c3710675afc0)
- First pass setting up github actions. [`d864037`](https://github.com/dustindall/footings/commit/d8640374ec8fe4728439b473b4e8aebe36be5410)
- updates to parameters and table_schema [`fe2681b`](https://github.com/dustindall/footings/commit/fe2681b7157f37459fa3f77d3e418b8da28e6b92)
- Updated LoadedFunction to not use a single callable not a list of callables. [`ce60b33`](https://github.com/dustindall/footings/commit/ce60b33ecf66163b9ce1bb218dddd7128cacbf14)
- Added setup file [`0a209a0`](https://github.com/dustindall/footings/commit/0a209a07491c82dd2ebef29f4b1fcb3561ecbc2c)
- Removed meta from footings and footings step. [`b604ec9`](https://github.com/dustindall/footings/commit/b604ec91eb4423b99df876eae603fa77150b4426)
- First pass on readme and added requirements to manifest.in. [`53d862c`](https://github.com/dustindall/footings/commit/53d862ce448adc39a5fb1eab43b7a7c9870f8723)
- task graph to use dispatcher. [`34f4ff9`](https://github.com/dustindall/footings/commit/34f4ff998d633c19a49aa57f4f0f46d1b2cc63fe)
- Updated model [`6f4266a`](https://github.com/dustindall/footings/commit/6f4266afc84d0c3e7ca221c56ac2017761a165c3)
- Moved from pylint to flask8. [`f7ae0d4`](https://github.com/dustindall/footings/commit/f7ae0d422a641b4173e5cdfa230f78b8696489af)
- Added ModelRunError capture. [`7d56f09`](https://github.com/dustindall/footings/commit/7d56f09c0d319616f2e0b31083b7a83bcea2c2a6)
- Cleaned and prepared footings module. [`a2e6e8e`](https://github.com/dustindall/footings/commit/a2e6e8e6f66fb894487fe81ae092838072f24818)
- Removal of some pylint wording. [`83348c1`](https://github.com/dustindall/footings/commit/83348c1bfa81a87317e4373771a992633b90b479)
- Removal of meta from model. [`0e9adf1`](https://github.com/dustindall/footings/commit/0e9adf18d2258562122c9b5fc9cf8a71fc445de3)
- Added repr=False to attr classes due to issue with cloudpickle. [`b63d8cc`](https://github.com/dustindall/footings/commit/b63d8cc3e4741dc129e1d8d380ec1ecf85fff486)
- Test .pre-commit. [`208b0fa`](https://github.com/dustindall/footings/commit/208b0fa1bc44669508d7884055cf67800db3bf6f)
- Fixed to readme.md. [`7d97ef6`](https://github.com/dustindall/footings/commit/7d97ef61f4c003b0fc9bce50be234aff4a902e67)
- Fixed ordering of init_args to correctly show the argument name within docstring. [`dddc5ac`](https://github.com/dustindall/footings/commit/dddc5ac67007fbdf45379586aeb4b0e4b9d9b1ff)
- fist to test_ffunction [`2c96f52`](https://github.com/dustindall/footings/commit/2c96f52082e279f8130a437ca06250e4676e0528)
- Updates to __init__.py. [`2b4ce27`](https://github.com/dustindall/footings/commit/2b4ce27fc5ee5c4c0c7ef211e48a15b90dc46b79)
- Reconfigured get_versions in __inti__.py [`b309248`](https://github.com/dustindall/footings/commit/b30924803a582f228b2be3781456940c8bc3766f)
- updates from black [`22e378e`](https://github.com/dustindall/footings/commit/22e378edfad9bb2c25e45b1b2bcc8e03739f7ef6)
- Bump version: 0.1.0 → 0.1.1 [`b3615b8`](https://github.com/dustindall/footings/commit/b3615b8ebf22caf2f2a5266955ed5daf83d13144)
- Update to .gitignore [`e4cb703`](https://github.com/dustindall/footings/commit/e4cb70304c3bd64231372914184e35eaa0426697)
- Removed None as default value [`dda6906`](https://github.com/dustindall/footings/commit/dda6906759081f4ec5366c9c9aade4eeb30679ea)
- Removed as_model_template [`412cfe3`](https://github.com/dustindall/footings/commit/412cfe330c0aa7c1172042d92b50bc4311de286f)
- Changed argument header from 'Arguments' to 'Attributes'. This aligns with the numpydoc standard. [`bd9ec4d`](https://github.com/dustindall/footings/commit/bd9ec4da5994d63d9121ebee9470cc3ae165bc98)
- Changed uses key to be under name. [`8467f81`](https://github.com/dustindall/footings/commit/8467f8158265823f8d1c61971382e66a2d5812d8)
- Added CI badge. [`c26fa90`](https://github.com/dustindall/footings/commit/c26fa908ab6f725b12d909f32ba567f8c6b97317)
- Added default parameter to default to None. [`55f4c99`](https://github.com/dustindall/footings/commit/55f4c9979e83922f6609d9cde9dac061acdc1843)
- Added items from footings to __init__.py [`241f31d`](https://github.com/dustindall/footings/commit/241f31d72d2a75e68ac795104e553abae546a2f7)
- Removed zzz.py. [`3f9df2a`](https://github.com/dustindall/footings/commit/3f9df2a48284736e8490010975e38f0cb5511cbc)
